"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const tape_1 = __importDefault(require("tape"));
const spl_token_1 = require("@solana/spl-token");
const utils_1 = require("../src/utils");
const transactions_1 = require("./transactions");
const utils_2 = require("./utils");
const js_1 = require("@metaplex-foundation/js");
const actions_1 = require("./actions");
(0, utils_2.killStuckProcess)();
(0, tape_1.default)('withdraw: success', async (t) => {
    const { payer, connection, transactionHandler } = await (0, actions_1.createPrerequisites)();
    const store = await (0, actions_1.createStore)({
        test: t,
        transactionHandler,
        payer,
        connection,
        params: {
            name: 'Store',
            description: 'Description',
        },
    });
    const { sellingResource, vault, vaultOwner, vaultOwnerBump, resourceMint, primaryMetadataCreators, } = await (0, actions_1.initSellingResource)({
        test: t,
        transactionHandler,
        payer,
        connection,
        store: store.publicKey,
        maxSupply: 100,
    });
    const { mint: treasuryMint, tokenAccount: userTokenAcc } = await (0, actions_1.mintNFT)({
        transactionHandler,
        payer,
        connection,
    });
    const startDate = Math.round(Date.now() / 1000) + 1;
    const params = {
        name: 'Market',
        description: '',
        startDate,
        endDate: null,
        mutable: true,
        price: 1,
        piecesInOneWallet: 1,
        gatingConfig: null,
    };
    const { market, treasuryHolder, treasuryOwnerBump, treasuryOwner } = await (0, actions_1.createMarket)({
        test: t,
        transactionHandler,
        payer,
        connection,
        store: store.publicKey,
        sellingResource: sellingResource.publicKey,
        treasuryMint: treasuryMint.publicKey,
        params,
    });
    await (0, utils_2.sleep)(3000);
    const [tradeHistory, tradeHistoryBump] = await (0, utils_1.findTradeHistoryAddress)(payer.publicKey, market.publicKey);
    const { mint: newMint, mintAta } = await (0, actions_1.mintTokenToAccount)({
        connection,
        payer: payer.publicKey,
        transactionHandler,
    });
    (0, utils_2.logDebug)('new mint', newMint.publicKey.toBase58());
    const metaplex = js_1.Metaplex.make(connection);
    const pdas = metaplex.nfts().pdas();
    const newMintEdition = pdas.edition({ mint: newMint.publicKey });
    const newMintMetadata = pdas.metadata({ mint: newMint.publicKey });
    const resourceMintMasterEdition = pdas.edition({ mint: resourceMint.publicKey });
    const resourceMintMetadata = pdas.metadata({ mint: resourceMint.publicKey });
    const resourceMintEditionMarker = pdas.editionMarker({
        mint: resourceMint.publicKey,
        edition: (0, js_1.toBigNumber)(1),
    });
    await (0, utils_2.sleep)(1000);
    const { tx: buyTx } = await (0, transactions_1.createBuyTransaction)({
        connection,
        buyer: payer.publicKey,
        userTokenAccount: userTokenAcc.publicKey,
        resourceMintMetadata,
        resourceMintEditionMarker,
        resourceMintMasterEdition,
        sellingResource: sellingResource.publicKey,
        market: market.publicKey,
        marketTreasuryHolder: treasuryHolder.publicKey,
        vaultOwner,
        tradeHistory,
        tradeHistoryBump,
        vault: vault.publicKey,
        vaultOwnerBump,
        newMint: newMint.publicKey,
        newMintEdition,
        newMintMetadata,
        newTokenAccount: mintAta.publicKey,
    });
    await transactionHandler.sendAndConfirmTransaction(buyTx, [payer]).assertSuccess(t);
    (0, utils_2.logDebug)('buy:: successful purchase');
    await (0, utils_2.sleep)(3000);
    const marketTx = await (0, transactions_1.closeMarket)({
        transactionHandler,
        payer,
        connection,
        market,
    });
    await transactionHandler.sendAndConfirmTransaction(marketTx, [payer]).assertSuccess(t);
    (0, utils_2.logDebug)(`market: ${market.publicKey}`);
    const [payoutTicket, payoutTicketBump] = await (0, utils_1.findPayoutTicketAddress)(market.publicKey, payer.publicKey);
    const destination = await (0, spl_token_1.getAssociatedTokenAddress)(treasuryMint.publicKey, payer.publicKey);
    const metadata = pdas.metadata({ mint: resourceMint.publicKey });
    const withdrawTx = await (0, transactions_1.createWithdrawTransaction)({
        connection,
        payer,
        market: market.publicKey,
        sellingResource: sellingResource.publicKey,
        metadata,
        treasuryHolder: treasuryHolder.publicKey,
        treasuryMint: treasuryMint.publicKey,
        destination,
        payoutTicket,
        payoutTicketBump,
        treasuryOwnerBump,
        treasuryOwner,
        primaryMetadataCreators,
    });
    await transactionHandler.sendAndConfirmTransaction(withdrawTx, [payer]).assertSuccess(t);
    const payoutTicketData = await connection.getAccountInfo(payoutTicket);
    t.ok(payoutTicketData === null || payoutTicketData === void 0 ? void 0 : payoutTicketData.owner);
});
// # sourceMappingURL=withdraw.test.js.map